|ci|_ |coveralls|_ |license|

rückenwind
==========

A python web framework based on tornado, jinja2, babel.


Documentation
=============

Head over to `Read The Docs <http://ruckenwind.readthedocs.org/en/latest/>`_ and read the docs! Or build the docs from source using: ``sphinx-build -b html docs/ docs.html/`` and enjoy locally.

Current State
=============

The framework does not yet provide a stable API.  When the API stabalizes the version is incremented to 1.x.  If used for anything that is remotely production-use make sure you stay within one 0.x branch of releases.  The current API (0.5.x / master) is not backward compatible to 0.4.x releases. The 0.4 branch is a major overhaul and is incompatible with 0.3.


.. |ci| image:: https://git.r0k.de/open-source/rueckenwind/badges/master/pipeline.svg
.. _ci: https://git.r0k.de/open-source/rueckenwind/pipelines

.. |coveralls| image:: https://img.shields.io/coveralls/FlorianLudwig/rueckenwind/master.svg?style=flat-square
.. _coveralls: https://coveralls.io/github/FlorianLudwig/rueckenwind?branch=master

.. |license| image:: https://img.shields.io/github/license/florianludwig/rueckenwind.svg?style=flat-square
